import { Option } from "./option";
export declare const emptyOk: <E>() => Result<void, E>;
export declare const emptyErr: <T>() => Result<T, void>;
export declare const ok: <T, E>(value: T) => Result<T, E>;
export declare const err: <T, E>(error: E) => Result<T, E>;
export interface Result<T, E> {
    isErr(): boolean;
    isOk(): boolean;
    ok(): Option<T>;
    err(): Option<E>;
    map<U>(fn: (value: T) => U): Result<U, E>;
    mapErr<F>(fn: (error: E) => F): Result<T, F>;
    mapOrElse<U>(fnMap: (value: T) => U, fnOrElse: (error: E) => U): U;
    and<U>(res: Result<U, E>): Result<U, E>;
    andThen<U>(fn: (value: T) => Result<U, E>): Result<U, E>;
    or<F>(res: Result<T, F>): Result<T, F>;
    orElse<F>(fn: (error: E) => Result<T, F>): Result<T, F>;
    expectErr(error: any): E;
    expect(error: any): T;
    unwrap(): T;
    unwrapErr(): E;
    unwrapOr(value: T): T;
    unwrapOrElse(fn: (error: E) => T): T;
}
export declare class Ok<T, E> implements Result<T, E> {
    private readonly value;
    constructor(value: T);
    isErr(): boolean;
    isOk(): boolean;
    ok(): Option<T>;
    err(): Option<E>;
    unwrap(): T;
    unwrapErr(): E;
    expectErr(error: any): E;
    expect(_error: any): T;
    unwrapOr(_value: T): T;
    unwrapOrElse(_fn: (error: E) => T): T;
    or<F>(_res: Result<T, F>): Result<T, F>;
    orElse<F>(_fn: (error: E) => Result<T, F>): Result<T, F>;
    and<U>(res: Result<U, E>): Result<U, E>;
    andThen<U>(fn: (value: T) => Result<U, E>): Result<U, E>;
    map<U>(fn: (value: T) => U): Result<U, E>;
    mapErr<F>(_fn: (error: E) => F): Result<T, F>;
    mapOrElse<U>(fnMap: (value: T) => U, fnOrElse: (error: E) => U): U;
}
export declare class Err<T, E> implements Result<T, E> {
    private readonly error;
    constructor(error: E);
    isErr(): boolean;
    isOk(): boolean;
    ok(): Option<T>;
    err(): Option<E>;
    unwrap(): T;
    unwrapErr(): E;
    expect(error: any): T;
    expectErr(_error: any): E;
    unwrapOr(value: T): T;
    unwrapOrElse(fn: (error: E) => T): T;
    or<F>(res: Result<T, F>): Result<T, F>;
    orElse<F>(fn: (error: E) => Result<T, F>): Result<T, F>;
    and<U>(_res: Result<U, E>): Result<U, E>;
    andThen<U>(_fn: (value: T) => Result<U, E>): Result<U, E>;
    map<U>(_fn: (value: T) => U): Result<U, E>;
    mapErr<F>(fn: (error: E) => F): Result<T, F>;
    mapOrElse<U>(fnMap: (value: T) => U, fnOrElse: (error: E) => U): U;
}
//# sourceMappingURL=result.d.ts.map